@@ -31,7 +31,7 @@ class Site(OralArgumentSite):
 
     def _get_case_dates(self):
         path = self.base_path + "//td[3]/span/text()"
-        return map(self._return_case_date, self.html.xpath(path))
+        return list(map(self._return_case_date, self.html.xpath(path)))
 
     @staticmethod
     def _return_case_date(s):
