@@ -1,5 +1,3 @@
-import re
-
 from lxml import etree
 
 from .reports import BaseReport
@@ -48,17 +46,6 @@ class PossibleCaseNumberApi(BaseReport):
         """
         self.tree = etree.fromstring(text)
 
-    def get_judge_abbrev(self, s):
-        """Get the judge abbreviation from the title string"""
-        regexes = [
-            r"\d\d-[a-zA-Z]{1,4}-\d{1,10}(-(?P<abbrev>.*?))? ",
-        ]
-        for regex in regexes:
-            m = re.search(regex, s)
-            if m:
-                return m.group("abbrev")
-        return ""
-
     def data(
         self, case_name=None, office_number=None, docket_number_letters=None
     ):
@@ -192,9 +179,6 @@ class PossibleCaseNumberApi(BaseReport):
                 # This could be further post processed to pull out the date closed
                 # and a cleaner title.
                 "title": force_unicode(node.xpath("./@title")[0]),
-                "judge_abbrev": self.get_judge_abbrev(
-                    node.xpath("./@title")[0]
-                ),
             }
         else:
             raise ParsingException("Unable to identify case.")
